@@ -5,7 +5,11 @@ DUMMY_ROLES = (
     'py:func',
 )
 
-def dummy_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
+def dummy_role(name, rawtext, text, lineno, inliner, options=None, content=None):
+    if options is None:
+        options = {}
+    if content is None:
+        content = []
     node = docutils.nodes.literal(rawtext, text, **options)
     return [node], []
 
