@@ -2,18 +2,19 @@ import re
 
 from django.views import debug
 
-debug.HIDDEN_SETTINGS = re.compile(debug.HIDDEN_SETTINGS.pattern + '|URL|CSRF|COOKIE')
+debug.HIDDEN_SETTINGS = re.compile(debug.HIDDEN_SETTINGS.pattern + '|URL|CSRF|COOKIE|csrftoken|sessionid')
 
 class SafeExceptionReporterFilter(debug.SafeExceptionReporterFilter):
     """
-    Safe exception reporter filter which also filters password from
-    request environment (``META``).
+    Safe exception reporter filter which also filters request environment
+    (``META``) and cookies (``COOKIES``) so that it is safer to share the
+    report publicly.
 
-    This is useful to not display password and other sensitive data passed to
+    This is useful to not display passwords and other sensitive data passed to
     Django through its process environment.
 
     Furthermore, it configures Django to additionally clean settings with
-    ``URL``, ``CSRF``, and ``COOKIE`` in keys.
+    ``URL``, ``CSRF``, ``COOKIE``, ``csrftoken``, and ``sessionid`` in keys.
 
     To install it, configure Django to::
 
@@ -30,5 +31,7 @@ class SafeExceptionReporterFilter(debug.SafeExceptionReporterFilter):
         for key in request.META:
             if key.isupper():
                 request.META[key] = debug.cleanse_setting(key, request.META[key])
+        for key in request.COOKIES:
+            request.COOKIES[key] = debug.cleanse_setting(key, request.COOKIES[key])
 
         return super(SafeExceptionReporterFilter, self).get_post_parameters(request)
