@@ -6,7 +6,7 @@ from django import template
 from django.core import urlresolvers
 from django.conf import settings
 from django.template import defaultfilters
-from django.utils import encoding, safestring
+from django.utils import encoding, html, safestring
 
 register = template.Library()
 
@@ -53,6 +53,8 @@ def fullurl(parser, token):
 
     return FullUrlNode(url)
 
+DASH_START_END_RE = re.compile(r'^-+|-+$')
+
 LATIN_MAP = {
     'À': 'A', 'Á': 'A', 'Â': 'A', 'Ã': 'A', 'Ä': 'A', 'Å': 'A', 'Æ': 'AE', 'Ç':
     'C', 'È': 'E', 'É': 'E', 'Ê': 'E', 'Ë': 'E', 'Ì': 'I', 'Í': 'I', 'Î': 'I',
@@ -188,7 +190,9 @@ def slugify2(value):
         value = downcode(value)
         value = unicodedata.normalize('NFD', value).encode('ascii', 'ignore')
         value = unicode(re.sub('[^\w\s-]', '', value).strip().lower())
-        return safestring.mark_safe(re.sub('[-\s]+', '-', value))
+        value = re.sub('[-\s]+', '-', value)
+        value = DASH_START_END_RE.sub('', value)
+        return safestring.mark_safe(value)
     except:
         if settings.TEMPLATE_DEBUG:
             raise
@@ -202,8 +206,91 @@ def unnamed_group_name(param):
     else:
         return param
 
-@register.simple_tag
-def urltemplate(viewname, *args, **kwargs):
+def urltemplate_with_prefix(resolver, view, prefix, *args, **kwargs):
+    if args and kwargs:
+        raise ValueError("Don't mix *args and **kwargs.")
+    elif args:
+        args = list(args)
+
+    possibilities = resolver.reverse_dict.getlist(view)
+
+    for possibility, pattern, defaults in possibilities:
+        assert len(possibility) > 0
+
+        if len(possibility) > 1:
+            raise NotImplementedError
+
+        result, params = possibility[0]
+
+        if kwargs and len(set(kwargs.keys()) - set(params)):
+            # Not all given pre-filled values exist in this URL pattern
+            continue
+
+        if args and len(params) < len(args):
+            # Too many pre-filled values for this URL pattern
+            continue
+
+        if args:
+            for i, param in enumerate(params):
+                if i < len(args):
+                    result = result.replace('%%(%s)s' % param, encoding.force_unicode(args[i]))
+                else:
+                    result = result.replace('%%(%s)s' % param, '{%s}' % unnamed_group_name(param))
+        else:
+            for param in params:
+                result = result.replace('%%(%s)s' % param, encoding.force_unicode(kwargs.get(param, '{%s}' % unnamed_group_name(param))))
+
+        return prefix + result
+
+    raise urlresolvers.NoReverseMatch("Reverse for '%s' with arguments '%s' and keyword arguments '%s' not found." % (view, args, kwargs))
+
+def urltemplate_namespaces(viewname, current_app=None, *args, **kwargs):
+    urlconf = urlresolvers.get_urlconf()
+    resolver = urlresolvers.get_resolver(urlconf)
+    prefix = urlresolvers.get_script_prefix()
+
+    parts = viewname.split(':')
+    parts.reverse()
+    view = parts[0]
+    path = parts[1:]
+
+    resolved_path = []
+    ns_pattern = ''
+    while path:
+        ns = path.pop()
+
+        # Lookup the name to see if it could be an app identifier
+        try:
+            app_list = resolver.app_dict[ns]
+            # Yes! Path part matches an app in the current Resolver
+            if current_app and current_app in app_list:
+                # If we are reversing for a particular app,
+                # use that namespace
+                ns = current_app
+            elif ns not in app_list:
+                # The name isn't shared by one of the instances
+                # (i.e., the default) so just pick the first instance
+                # as the default.
+                ns = app_list[0]
+        except KeyError:
+            pass
+
+        try:
+            extra, resolver = resolver.namespace_dict[ns]
+            resolved_path.append(ns)
+            ns_pattern = ns_pattern + extra
+        except KeyError, key:
+            if resolved_path:
+                raise urlresolvers.NoReverseMatch("%s is not a registered namespace inside '%s'" % (key, ':'.join(resolved_path)))
+            else:
+                raise urlresolvers.NoReverseMatch("%s is not a registered namespace" % key)
+    if ns_pattern:
+        resolver = urlresolvers.get_ns_resolver(ns_pattern, resolver)
+
+    return urltemplate_with_prefix(resolver, view, prefix, *args, **kwargs)
+
+@register.simple_tag(takes_context=True)
+def urltemplate(context, viewname, *args, **kwargs):
     """
     Creates URI template in a similar way to how ``url`` tags work but leaving parts of
     a URI to be filled in by a client. See :rfc:`6570` for more information.
@@ -233,46 +320,68 @@ def urltemplate(viewname, *args, **kwargs):
     """
 
     try:
-        if args and kwargs:
-            raise ValueError("Don't mix *args and **kwargs.")
-        elif args:
-            args = list(args)
+        url = urltemplate_namespaces(viewname, context.current_app, *args, **kwargs)
+        if context.autoescape:
+            url = html.conditional_escape(url)
+        return safestring.mark_safe(url)
+    except:
+        if settings.TEMPLATE_DEBUG:
+            raise
+        else:
+            return u''
+
+@register.simple_tag(takes_context=True)
+def active_url(context, urls, class_name='active'):
+    """
+    Returns ``class_name`` (default ``active``) if any of given ``urls`` are real prefixes
+    of the current request path.
+
+    Useful when you want to highlight links to the current section of the site. For example,
+    in menu entries.
+
+    Example usage::
+
+        {% active_url "/test/" %}
+    """
+
+    if not urls:
+        return u''
+
+    if not hasattr(urls, '__iter__'):
+        urls = [urls]
+
+    try:
+        for url in urls:
+            # To make sure we use resolved lazy instances,
+            # otherwise there are sometimes errors
+            url = encoding.force_unicode(url)
+
+            if not url:
+                continue
 
-        urlconf = urlresolvers.get_urlconf()
-        resolver = urlresolvers.get_resolver(urlconf)
-        prefix = urlresolvers.get_script_prefix()
-
-        possibilities = resolver.reverse_dict.getlist(viewname)
-
-        for possibility, pattern, defaults in possibilities:
-            assert len(possibility) > 0
-
-            if len(possibility) > 1:
-                raise NotImplementedError
+            if url.startswith('/'):
+                current_url = context['request'].path
+            else:
+                current_url = context['request'].build_absolute_uri(context['request'].path)
 
-            result, params = possibility[0]
+            if url == current_url:
+                return class_name
 
-            if kwargs and len(set(kwargs.keys()) - set(params)):
-                # Not all given pre-filled values exist in this URL pattern
+            if url == '/':
+                # If url is / it would match anything
+                # It should be true only if current_url is /,
+                # which we tested already above
                 continue
-
-            if args and len(params) < len(args):
-                # Too many pre-filled values for this URL pattern
-                continue
-
-            if args:
-                for i, param in enumerate(params):
-                    if i < len(args):
-                        result = result.replace('%%(%s)s' % param, encoding.force_unicode(args[i]))
-                    else:
-                        result = result.replace('%%(%s)s' % param, '{%s}' % unnamed_group_name(param))
-            else:
-                for param in params:
-                    result = result.replace('%%(%s)s' % param, encoding.force_unicode(kwargs.get(param, '{%s}' % unnamed_group_name(param))))
 
-            return prefix + result
+            # True if url is a real prefix of current_url
+            # We test for equality above, so if it is a prefix
+            # then current_url is for sure longer, so we test
+            # that prefix ends with /, to make sure it is a real
+            # path prefix
+            if current_url.startswith(url) and current_url.startswith('%s/' % url):
+                return class_name
 
-        raise urlresolvers.NoReverseMatch("Reverse for '%s' with arguments '%s' and keyword arguments '%s' not found." % (viewname, args, kwargs))
+        return u''
     except:
         if settings.TEMPLATE_DEBUG:
             raise
